@@ -27,6 +27,9 @@ class dyagram:
 
         self.inventory_file = inventory_file
         self.verbose = verbose
+        self.log = None
+        self.setup_logging()
+
         self.inventory_object = self.get_inv_yaml_obj()
         self._devices_to_query = Queue()
         self._devices_queried = []
@@ -44,8 +47,7 @@ class dyagram:
 
         self._load_creds()
         self._load_inventory()
-        self.log = None
-        self.setup_logging()
+
 
 
     def setup_logging(self):
@@ -679,28 +681,28 @@ def main():
 
 
 
-    if args.first_arg[0].lower() == "discover":
+    if args.dyagram_args[0].lower() == "discover":
         print("\n\n-- DyaGram Discovering Started --\n")
         dy = dyagram()
         dy.discover()
         print("\n\n-- DyaGram Discovering Completed --\n")
 
-    if args.first_arg[0].lower() == "site":
+    if args.dyagram_args[0].lower() == "site":
         from dyagram.sites.sites import sites
         s = sites()
-        if len(args.first_arg) == 1:
+        if len(args.dyagram_args) == 1:
             s.list_sites_in_cli()
-        elif len(args.first_arg) > 1:
-            if args.first_arg[1].lower() == "new":
+        elif len(args.dyagram_args) > 1:
+            if args.dyagram_args[1].lower() == "new":
                 try:
-                    s.make_new_site(args.first_arg[2])
+                    s.make_new_site(args.dyagram_args[2])
                 except Exception as e:
                     print("Missing argument : <site>")
-            if args.first_arg[1].lower() == "switch":
+            if args.dyagram_args[1].lower() == "switch":
                 try:
-                    s.switch_site(args.first_arg[2].lower())
+                    s.switch_site(args.dyagram_args[2].lower())
                 except:
-                    print(f"Site {args.first_arg[2]} doesn't exist")
+                    print(f"Site {args.dyagram_args[2]} doesn't exist")
 
 
 if __name__ == "__main__":
